==> nan_common_utils-0.0.11.tar.gz: lib/nan_common_show_uploadImg_widget.dart <==

import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:nan_common_utils/nan_util.dart';
import 'package:nan_common_utils/nan_widget_util.dart';

class NanCommonShowUploadImgWidget extends StatefulWidget{

  final List imageFiles;
  final String title;
  NanCommonShowUploadImgWidget({
    Key key,
    this.title="现场图片",
    this.imageFiles
  }):super(key:key);

  @override
  NanCommonShowUploadImgWidgetState createState() => NanCommonShowUploadImgWidgetState();

}

class NanCommonShowUploadImgWidgetState extends State<NanCommonShowUploadImgWidget>{
  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Offstage(
      offstage: widget.imageFiles.length>0 ? false:true,
      child: Column(
        children: <Widget>[
          Container(
            // margin: EdgeInsets.only(top: 15),
            width: NanUtil.kScreenWidth,
            alignment: Alignment.centerLeft,
            constraints: BoxConstraints(
              minHeight: 50
            ),
            color: Colors.white,
            padding: EdgeInsets.only(left: 20),
            child: Text(widget.title,style: TextStyle(fontSize: 15,fontWeight: FontWeight.bold,color: Color.fromRGBO(102,102,102, 1))),
          ),
          Divider(height: 1,),
          Container(
            width: NanUtil.kScreenWidth,
            color:Colors.white,
            child: Container(
              padding: EdgeInsets.fromLTRB(32, 16, 32, 8),
              child: GridView.builder(
                shrinkWrap: true, //解决 listview 嵌套报错
                physics: NeverScrollableScrollPhysics(), //禁用滑动事件
                gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                    //横轴元素个数
                    crossAxisCount: 4,
                    //纵轴间距
                    mainAxisSpacing: 5.0,
                    //横轴间距
                    crossAxisSpacing: 5.0,
                    //子组件宽高长度比例
                    childAspectRatio: 1.0),
                itemBuilder: (BuildContext context, int index) {
                  String filePath = NanUtil.isEmpty(widget.imageFiles[index]["filePath"]);
                  return NanWidgetUtil.cachedNetworkImageWidget(context, index, widget.imageFiles, filePath);
                },
                itemCount: widget.imageFiles.length,
              ),
            ),
          )
        ],
      ),
    );
  }
}

==> nan_common_utils-0.0.37.tar.gz: lib/nan_common_show_uploadImg_widget.dart <==

import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:nan_common_utils/nan_photo_view_page.dart';
import 'package:nan_common_utils/nan_util.dart';
import 'package:nan_common_utils/nan_widget_util.dart';

class NanCommonShowUploadImgWidget extends StatefulWidget{

  final List imageFiles;
  final String title;
  final Color navBgColor;
  NanCommonShowUploadImgWidget({
    Key key,
    this.title="现场图片",
    this.imageFiles,
    this.navBgColor = Colors.white
  }):super(key:key);

  @override
  NanCommonShowUploadImgWidgetState createState() => NanCommonShowUploadImgWidgetState();

}

class NanCommonShowUploadImgWidgetState extends State<NanCommonShowUploadImgWidget>{
  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Offstage(
      offstage: widget.imageFiles.length>0 ? false:true,
      child: Column(
        children: <Widget>[
          Container(
            // margin: EdgeInsets.only(top: 15),
            width: NanUtil.kScreenWidth,
            alignment: Alignment.centerLeft,
            constraints: BoxConstraints(
              minHeight: 50
            ),
            color: Colors.white,
            padding: EdgeInsets.only(left: 20),
            child: Text(widget.title,style: TextStyle(fontSize: 15,fontWeight: FontWeight.bold,color: Color.fromRGBO(102,102,102, 1))),
          ),
          Divider(height: 1,),
          Container(
            width: NanUtil.kScreenWidth,
            color:Colors.white,
            child: Container(
              padding: EdgeInsets.fromLTRB(32, 16, 32, 8),
              child: GridView.builder(
                shrinkWrap: true, //解决 listview 嵌套报错
                physics: NeverScrollableScrollPhysics(), //禁用滑动事件
                gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
                    //横轴元素个数
                    crossAxisCount: 4,
                    //纵轴间距
                    mainAxisSpacing: 5.0,
                    //横轴间距
                    crossAxisSpacing: 5.0,
                    //子组件宽高长度比例
                    childAspectRatio: 1.0),
                itemBuilder: (BuildContext context, int index) {
                  String filePath = NanUtil.isEmpty(widget.imageFiles[index]["filePath"]);
                  return NanWidgetUtil.cachedNetworkImageWidget(context, index, widget.imageFiles, filePath,onTap: (){
                    Navigator.push(context, MaterialPageRoute(builder: (context)=>PhotoViewPage(index: index,photoList: widget.imageFiles,navBgColor: widget.navBgColor,)));
                  });
                },
                itemCount: widget.imageFiles.length,
              ),
            ),
          )
        ],
      ),
    );
  }
}
